@@ -252,7 +252,7 @@ class WindowsProtocolHandler:
         
         if rediacc_exe:
             # Use the rediacc.exe directly for protocol handling
-            return f'"{rediacc_exe}" protocol-handler "%1"'
+            return f'"{rediacc_exe}" protocol run "%1"'
         else:
             # Fallback to Python + script method (original behavior)
             logger.warning("Could not locate rediacc.exe, falling back to Python script method")
@@ -265,7 +265,7 @@ class WindowsProtocolHandler:
             
             if wrapper_script.exists():
                 # Always use the wrapper script for consistency
-                return f'"{python_exe}" "{wrapper_script}" protocol-handler "%1"'
+                return f'"{python_exe}" "{wrapper_script}" protocol run "%1"'
             else:
                 # If wrapper doesn't exist, try to find it relative to the installed package
                 # This handles cases where the package is installed via pip
@@ -274,11 +274,11 @@ class WindowsProtocolHandler:
                 wrapper_script = cli_package_dir / "rediacc.py"
                 
                 if wrapper_script.exists():
-                    return f'"{python_exe}" "{wrapper_script}" protocol-handler "%1"'
+                    return f'"{python_exe}" "{wrapper_script}" protocol run "%1"'
                 else:
                     # Last resort: assume rediacc.py is in the current working directory
                     # or accessible via PATH
-                    return f'"{python_exe}" rediacc.py protocol-handler "%1"'
+                    return f'"{python_exe}" rediacc.py protocol run "%1"'
     
     def check_admin_privileges(self) -> bool:
         """Check if running with administrator privileges"""
@@ -447,7 +447,7 @@ class WindowsProtocolHandler:
 class ProtocolUrlParser:
     """Parse and handle rediacc:// protocol URLs"""
     
-    VALID_ACTIONS = {"sync", "terminal", "plugin", "browser", "desktop"}
+    VALID_ACTIONS = {"sync", "terminal", "plugin", "browser", "desktop", "vscode"}
     PROTOCOL_SCHEME = "rediacc"
     
     def __init__(self):
@@ -647,6 +647,17 @@ class ProtocolUrlParser:
             if "path" in params:
                 cmd.extend(["--path", params["path"]])
 
+        elif action == "vscode":
+            # VSCode action - launches VSCode with SSH remote connection
+            cmd = ["vscode"]
+            cmd.extend(["--token", token, "--team", team, "--machine", machine])
+            # Only add repository if it's provided and not empty
+            if repository and repository.strip():
+                cmd.extend(["--repo", repository])
+            # Optional path parameter for specific directory
+            if "path" in params:
+                cmd.extend(["--path", params["path"]])
+
         else:
             raise ValueError(f"Unsupported action: {action}")
         
@@ -758,20 +769,89 @@ def handle_protocol_url(url: str, is_protocol_call: bool = False) -> int:
                     exit_code = e.code if e.code is not None else 1
 
             elif action == "terminal":
-                # Import and call term_main directly
-                try:
+                # Check if we're running in a terminal (command line) or not (browser protocol call)
+                has_terminal = sys.stdin.isatty() and sys.stdout.isatty()
+
+                if not has_terminal and is_protocol_call:
+                    # Called from browser without terminal - launch in new terminal window
                     try:
-                        from ..commands import term_main
+                        from .config import TerminalDetector, get_cli_root
+
+                        # Build the rediacc command
+                        rediacc_cmd = ' '.join(cmd_args)
+                        logger.info(f"Launching terminal for command: {rediacc_cmd}")
+
+                        # Detect best terminal
+                        detector = TerminalDetector()
+                        method = detector.detect()
+
+                        if not method:
+                            logger.error("No working terminal emulator found")
+                            command_error = "No working terminal emulator found on your system"
+                            exit_code = 1
+                        else:
+                            # Get launch function
+                            launch_func = detector.get_launch_function(method)
+                            if launch_func:
+                                cli_dir = str(get_cli_root())
+                                logger.info(f"Launching terminal with method '{method}': {rediacc_cmd}")
+                                launch_func(cli_dir, rediacc_cmd, "Rediacc Terminal")
+                                exit_code = 0
+                                logger.info("Terminal launched successfully")
+                            else:
+                                logger.error(f"Launch function not found for method: {method}")
+                                command_error = f"Failed to get launch function for terminal method: {method}"
+                                exit_code = 1
+                    except Exception as e:
+                        logger.error(f"Failed to launch terminal: {e}", exc_info=True)
+                        command_error = f"Failed to launch terminal: {e}"
+                        exit_code = 1
+                else:
+                    # Running in terminal (command line call) - execute directly
+                    try:
+                        # Disable bytecode writing to avoid permission issues in installed packages
+                        dont_write_bytecode = sys.dont_write_bytecode
+                        sys.dont_write_bytecode = True
+
+                        try:
+                            from ..commands import term_main
+                        except ImportError:
+                            # Fallback for when relative imports don't work
+                            sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'commands'))
+                            import term_main
+                        finally:
+                            sys.dont_write_bytecode = dont_write_bytecode
+
+                        sys.argv = ["rediacc-term"] + cmd_args[1:]
+                        exit_code = term_main.main()
+                    except ImportError as e:
+                        logger.error(f"Failed to import term module: {e}")
+                        command_error = f"Failed to import term module: {e}"
+                        exit_code = 1
+                    except SystemExit as e:
+                        exit_code = e.code if e.code is not None else 1
+
+            elif action == "vscode":
+                # Import and call vscode_main directly
+                try:
+                    # Disable bytecode writing to avoid permission issues in installed packages
+                    dont_write_bytecode = sys.dont_write_bytecode
+                    sys.dont_write_bytecode = True
+
+                    try:
+                        from ..commands import vscode_main
                     except ImportError:
                         # Fallback for when relative imports don't work
                         sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'commands'))
-                        import term_main
-                    
-                    sys.argv = ["rediacc-term"] + cmd_args[1:]
-                    exit_code = term_main.main()
+                        import vscode_main
+                    finally:
+                        sys.dont_write_bytecode = dont_write_bytecode
+
+                    sys.argv = ["rediacc-vscode"] + cmd_args[1:]
+                    exit_code = vscode_main.main()
                 except ImportError as e:
-                    logger.error(f"Failed to import term module: {e}")
-                    command_error = f"Failed to import term module: {e}"
+                    logger.error(f"Failed to import vscode module: {e}")
+                    command_error = f"Failed to import vscode module: {e}"
                     exit_code = 1
                 except SystemExit as e:
                     exit_code = e.code if e.code is not None else 1
@@ -779,13 +859,19 @@ def handle_protocol_url(url: str, is_protocol_call: bool = False) -> int:
             elif action in ["plugin", "browser"]:
                 # Import and call cli_main directly
                 try:
+                    # Disable bytecode writing to avoid permission issues in installed packages
+                    dont_write_bytecode = sys.dont_write_bytecode
+                    sys.dont_write_bytecode = True
+
                     try:
                         from ..commands import cli_main
                     except ImportError:
                         # Fallback for when relative imports don't work
                         sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'commands'))
                         import cli_main
-                    
+                    finally:
+                        sys.dont_write_bytecode = dont_write_bytecode
+
                     sys.argv = ["rediacc"] + cmd_args
                     exit_code = cli_main.main()
                 except ImportError as e:
@@ -798,13 +884,19 @@ def handle_protocol_url(url: str, is_protocol_call: bool = False) -> int:
             elif action == "desktop":
                 # Import and call desktop GUI directly
                 try:
+                    # Disable bytecode writing to avoid permission issues in installed packages
+                    dont_write_bytecode = sys.dont_write_bytecode
+                    sys.dont_write_bytecode = True
+
                     try:
                         from ..gui.main import launch_gui
                     except ImportError:
                         # Fallback for when relative imports don't work
                         sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'gui'))
                         from main import launch_gui
-                    
+                    finally:
+                        sys.dont_write_bytecode = dont_write_bytecode
+
                     # Pass arguments to desktop GUI for preselection
                     sys.argv = ["rediacc-desktop"] + cmd_args[1:]
                     launch_gui()  # This function calls sys.exit() internally
